summaryrefslogtreecommitdiffstats
path: root/kmymoney2/views/kmymoneyview.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmymoney2/views/kmymoneyview.h')
-rw-r--r--kmymoney2/views/kmymoneyview.h98
1 files changed, 50 insertions, 48 deletions
diff --git a/kmymoney2/views/kmymoneyview.h b/kmymoney2/views/kmymoneyview.h
index 13e3d76..e1c1266 100644
--- a/kmymoney2/views/kmymoneyview.h
+++ b/kmymoney2/views/kmymoneyview.h
@@ -24,10 +24,10 @@
// ----------------------------------------------------------------------------
// QT Includes
-#include <qwidget.h>
-class QVBox;
-class QFile;
-class QVBoxLayout;
+#include <tqwidget.h>
+class TQVBox;
+class TQFile;
+class TQVBoxLayout;
// ----------------------------------------------------------------------------
// KDE Includes
@@ -65,7 +65,7 @@ class TransactionEditor;
class KForecastView;
/**
- * This class represents the view of the MyMoneyFile which contains
+ * This class represents the view of the MyMoneyFile which tqcontains
* Banks/Accounts/Transactions, Recurring transactions (or Bills & Deposits)
* and scripts (yet to be implemented). Each different aspect of the file
* is represented by a tab within the view.
@@ -77,6 +77,7 @@ class KForecastView;
class KMyMoneyView : public KJanusWidget
{
Q_OBJECT
+ TQ_OBJECT
public:
enum viewID {
@@ -127,17 +128,17 @@ private:
KReportsView* m_reportsView;
KForecastView* m_forecastView;
- QVBox* m_homeViewFrame;
- QVBox* m_accountsViewFrame;
- QVBox* m_institutionsViewFrame;
- QVBox* m_categoriesViewFrame;
- QVBox* m_payeesViewFrame;
- QVBox* m_budgetViewFrame;
- QVBox* m_scheduleViewFrame;
- QVBox* m_ledgerViewFrame;
- QVBox* m_investmentViewFrame;
- QVBox* m_reportsViewFrame;
- QVBox* m_forecastViewFrame;
+ TQVBox* m_homeViewFrame;
+ TQVBox* m_accountsViewFrame;
+ TQVBox* m_institutionsViewFrame;
+ TQVBox* m_categoriesViewFrame;
+ TQVBox* m_payeesViewFrame;
+ TQVBox* m_budgetViewFrame;
+ TQVBox* m_scheduleViewFrame;
+ TQVBox* m_ledgerViewFrame;
+ TQVBox* m_investmentViewFrame;
+ TQVBox* m_reportsViewFrame;
+ TQVBox* m_forecastViewFrame;
bool m_inConstructor;
@@ -161,9 +162,9 @@ private:
fileTypeE m_fileType;
private:
- void addTitleBar(QWidget* parent, const QString& title);
+ void addTitleBar(TQWidget* tqparent, const TQString& title);
- void ungetString(QIODevice *qfile, char * buf, int len);
+ void ungetString(TQIODevice *qfile, char * buf, int len);
/**
* This method creates the currency @p curr if it does not exist and
@@ -180,7 +181,7 @@ private:
/**
*
*/
- void loadAncientCurrency(const QString& id, const QString& name, const QString& sym, const QDate& date, const MyMoneyMoney& rate, const QString& newId, const int partsPerUnit = 100, const int smallestCashFraction = 100, const int smallestAccountFraction = 0);
+ void loadAncientCurrency(const TQString& id, const TQString& name, const TQString& sym, const TQDate& date, const MyMoneyMoney& rate, const TQString& newId, const int partsPerUnit = 100, const int smallestCashFraction = 100, const int smallestAccountFraction = 0);
/**
* if no base currency is defined, start the dialog and force it to be set
@@ -200,9 +201,9 @@ private:
*/
void removeStorage(void);
- void viewAccountList(const QString& selectAccount); // Show the accounts view
+ void viewAccountList(const TQString& selectAccount); // Show the accounts view
- static void progressCallback(int current, int total, const QString&);
+ static void progressCallback(int current, int total, const TQString&);
/**
*/
@@ -222,14 +223,14 @@ private:
void createSchedule(MyMoneySchedule s, MyMoneyAccount& a);
- void checkAccountName(const MyMoneyAccount& acc, const QString& name) const;
+ void checkAccountName(const MyMoneyAccount& acc, const TQString& name) const;
public:
/**
* The constructor for KMyMoneyView. Just creates all the tabs for the
* different aspects of the MyMoneyFile.
*/
- KMyMoneyView(QWidget *parent=0, const char *name=0);
+ KMyMoneyView(TQWidget *tqparent=0, const char *name=0);
/**
* Destructor
@@ -266,14 +267,14 @@ public:
*
* @param url The URL to save into.
* If no protocol is specified, file:// is assumed.
* @param keyList QString containing a comma separated list of keys
* to be used for encryption. If @p keyList is empty,
* the file will be saved unencrypted (the default)
*
* @retval false save operation failed
* @retval true save operation was successful
*/
- bool saveFile(const KURL& url, const QString& keyList = QString());
+ bool saveFile(const KURL& url, const TQString& keyList = TQString());
/**
* Saves the data into permanent storage on a new or empty SQL database.
*
@@ -340,9 +341,9 @@ public:
*/
void enableViews(int state = -1);
- KMyMoneyViewBase* addPage(const QString& title, const QString& icon = QString());
+ KMyMoneyViewBase* addPage(const TQString& title, const TQString& icon = TQString());
- void addWidget(QWidget* w);
+ void addWidget(TQWidget* w);
virtual bool showPage(int index);
@@ -357,7 +358,7 @@ public:
* @retval true Yes, view allows to create a transaction (tooltip is not changed)
* @retval false No, view cannot to create a transaction (tooltip is updated with message)
*/
- bool canCreateTransactions(const KMyMoneyRegister::SelectedTransactions& list, QString& tooltip) const;
+ bool canCreateTransactions(const KMyMoneyRegister::SelectedTransactions& list, TQString& tooltip) const;
/**
* check if the current view allows to modify (edit/delete) the selected transactions
@@ -370,9 +371,9 @@ public:
* @retval true Yes, view allows to edit/delete transactions (tooltip is not changed)
* @retval false No, view cannot edit/delete transactions (tooltip is updated with message)
*/
- bool canModifyTransactions(const KMyMoneyRegister::SelectedTransactions& list, QString& tooltip) const;
+ bool canModifyTransactions(const KMyMoneyRegister::SelectedTransactions& list, TQString& tooltip) const;
- bool canDuplicateTransactions(const KMyMoneyRegister::SelectedTransactions& list, QString& tooltip) const;
+ bool canDuplicateTransactions(const KMyMoneyRegister::SelectedTransactions& list, TQString& tooltip) const;
/**
* check if the current view allows to edit the selected transactions
@@ -385,7 +386,7 @@ public:
* @retval true Yes, view allows to enter/edit transactions
* @retval false No, view cannot enter/edit transactions
*/
- bool canEditTransactions(const KMyMoneyRegister::SelectedTransactions& list, QString& tooltip) const;
+ bool canEditTransactions(const KMyMoneyRegister::SelectedTransactions& list, TQString& tooltip) const;
/**
* check if the current view allows to print something
@@ -410,7 +411,7 @@ public:
* @retval true Reconciliation started
* @retval false Account cannot be reconciled
*/
- bool startReconciliation(const MyMoneyAccount& account, const QDate& reconciliationDate, const MyMoneyMoney& endingBalance);
+ bool startReconciliation(const MyMoneyAccount& account, const TQDate& reconciliationDate, const MyMoneyMoney& endingBalance);
/**
* Used to finish reconciliation of account @a account. It switches the
@@ -437,7 +438,7 @@ public slots:
*
* @param widget pointer to page widget
*/
- void slotRememberPage(QWidget* widget);
+ void slotRememberPage(TQWidget* widget);
/**
* Brings up a dialog to change the list(s) settings and saves them into the
@@ -445,7 +446,7 @@ public slots:
*
* @see KListSettingsDlg
* Refreshs all views. Used e.g. after settings have been changed or
- * data has been loaded from external sources (QIF import).
+ * data has been loaded from external sources (TQIF import).
**/
void slotRefreshViews();
@@ -457,7 +458,7 @@ public slots:
* @param acc The ID of the account to be shown
* @param transaction The ID of the transaction to be selected
*/
- void slotLedgerSelected(const QString& acc, const QString& transaction = QString());
+ void slotLedgerSelected(const TQString& acc, const TQString& transaction = TQString());
/**
* Called, whenever the payees view should pop up and a specific
@@ -467,7 +468,7 @@ public slots:
* @param accountId The ID of the account to be shown
* @param transactionId The ID of the transaction to be selected
*/
- void slotPayeeSelected(const QString& payeeId, const QString& accountId, const QString& transactionId);
+ void slotPayeeSelected(const TQString& payeeId, const TQString& accountId, const TQString& transactionId);
/**
* Called, whenever the schedule view should pop up and a specific
@@ -475,7 +476,7 @@ public slots:
*
* @param schedule The ID of the schedule to be shown
*/
- void slotScheduleSelected(const QString& schedule);
+ void slotScheduleSelected(const TQString& schedule);
/**
* Called, whenever the report view should pop up and a specific
@@ -483,7 +484,7 @@ public slots:
*
* @param reportid The ID of the report to be shown
*/
- void slotShowReport(const QString& reportid);
+ void slotShowReport(const TQString& reportid);
/**
* Same as the above, but the caller passes in an actual report
@@ -546,15 +547,15 @@ private:
* the final destination is reached over a network
* protocol (e.g. FTP)
*
* @param qf pointer to QFile representing the opened file
* @param writer pointer to the formatter
* @param plaintext whether to override any compression & encryption settings
* @param keyList QString containing a comma separated list of keys to be used for encryption
* If @p keyList is empty, the file will be saved unencrypted
*
* @note This method will close the file when it is written.
*/
- void saveToLocalFile(QFile* qf, IMyMoneyStorageFormat* writer, bool plaintext=false, const QString& keyList = QString());
+ void saveToLocalFile(TQFile* qf, IMyMoneyStorageFormat* writer, bool plaintext=false, const TQString& keyList = TQString());
/**
* Internal method used by slotAccountNew() and slotAccountCategory().
@@ -587,7 +588,7 @@ signals:
* @param endingBalance collected ending balance when reconciliation starts
* 0 otherwise
*/
- void reconciliationStarts(const MyMoneyAccount& account, const QDate& reconciliationDate, const MyMoneyMoney& endingBalance);
+ void reconciliationStarts(const MyMoneyAccount& account, const TQDate& reconciliationDate, const MyMoneyMoney& endingBalance);
};
@@ -595,16 +596,17 @@ signals:
* This class is an abstract base class that all specific views
* should be based on.
*/
-class KMyMoneyViewBase : public QWidget
+class KMyMoneyViewBase : public TQWidget
{
Q_OBJECT
+ TQ_OBJECT
public:
- KMyMoneyViewBase(QWidget* parent, const char *name, const QString& title);
+ KMyMoneyViewBase(TQWidget* tqparent, const char *name, const TQString& title);
virtual ~KMyMoneyViewBase();
- void setTitle(const QString& title);
- QVBoxLayout* layout(void) const;
- void addWidget(QWidget* w);
+ void setTitle(const TQString& title);
+ TQVBoxLayout* tqlayout(void) const;
+ void addWidget(TQWidget* w);
/**
* This method is used to edit the currently selected transactions
@@ -614,7 +616,7 @@ public:
* @retval false view was not capable to edit transactions
* @retval true view was capable to edit the transactions and did so
*/
- bool editTransactions(const QValueList<MyMoneyTransaction>& transactions) const { Q_UNUSED(transactions) return false; }
+ bool editTransactions(const TQValueList<MyMoneyTransaction>& transactions) const { Q_UNUSED(transactions) return false; }
private:
/// \internal d-pointer class.
class Private;
@@ -266,14 +267,14 @@ public:
* @param url The URL to save into.
* If no protocol is specified, file:// is assumed.
- * @param keyList QString containing a comma separated list of keys
+ * @param keyList TQString containing a comma separated list of keys
* to be used for encryption. If @p keyList is empty,
* the file will be saved unencrypted (the default)
@@ -546,15 +547,15 @@ private:
* protocol (e.g. FTP)
*
- * @param qf pointer to QFile representing the opened file
+ * @param qf pointer to TQFile representing the opened file
* @param writer pointer to the formatter
* @param plaintext whether to override any compression & encryption settings
@@ -546,15 +547,15 @@ private:
* @param writer pointer to the formatter
* @param plaintext whether to override any compression & encryption settings
- * @param keyList QString containing a comma separated list of keys to be used for encryption
+ * @param keyList TQString containing a comma separated list of keys to be used for encryption
* If @p keyList is empty, the file will be saved unencrypted
*